ImageLayout

Enum ImageLayout 

pub enum ImageLayout {
    Optimal,
    General,
    GeneralAndPresentation,
}
Defines a handful of layout options for images. Rather than a list of all possible image layouts, this reduced list is correlated with the access types to map to the correct Vulkan layouts. Optimal is usually preferred.

Variants



Optimal

Choose the most optimal layout for each usage. Performs layout transitions as appropriate for the access.



General

Layout accessible by all Vulkan access types on a device - no layout transitions except for presentation



GeneralAndPresentation

Similar to General, but also allows presentation engines to access it - no layout transitions. Requires VK_KHR_shared_presentable_image to be enabled, and this can only be used for shared presentable images (i.e. single-buffered swap chains).